<?php

namespace Drupal\inspector_monitoring\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Inspector settings form.
 */
class InspectorSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'inspector_monitoring.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'inspector_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('inspector_monitoring.settings');

    $form['ingestion_key'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Ingestion Key'),
      '#description' => $this->t('This key enable data transfer from your server to Inspector.'),
      '#default_value' => $config->get('ingestion_key'),
    ];

    $form['transport'] = [
      '#type' => 'select',
      '#title' => $this->t('Transport'),
      '#description' => $this->t('Tha way the package sends data to the Inspector API. "sync" (using php curl extension), "async" (in the background)'),
      '#default_value' => $config->get('transport') ?? 'sync',
      '#options' => [
        'async' => $this->t('Async'),
        'sync' => $this->t('Sync'),
      ],
    ];

    $form['enable_query_logging'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Enable Query Logging'),
      '#default_value' => $config->get('enable_query_logging'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    if (!$form_state->getValue('ingestion_key')) {
      $form_state->setErrorByName('ingestion_key', $this->t('Ingestion Key is required.'));
    }

    if (!$form_state->getValue('transport')) {
      $form_state->setErrorByName('transport', $this->t('Transport is required.'));
    }

    parent::validateForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('inspector_monitoring.settings')
      ->set('ingestion_key', $form_state->getValue('ingestion_key'))
      ->set('enable_query_logging', $form_state->getValue('enable_query_logging'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
