<?php

namespace Drupal\inspector_monitoring;

use Drupal\Core\Config\BootstrapConfigStorageFactory;
use Drupal\Core\DependencyInjection\ContainerBuilder;
use Drupal\Core\DependencyInjection\ServiceProviderBase;
use Drupal\inspector_monitoring\Middleware\DBEventsEnabler;
use Drupal\inspector_monitoring\Service\Inspector;
use Drupal\inspector_monitoring\Subscribers\DBEventsSubscriber;
use Symfony\Component\DependencyInjection\Reference;

/**
 * Service provider for the inspector monitoring module.
 */
class InspectorMonitoringServiceProvider extends ServiceProviderBase {

  /**
   * Registers services with the container.
   *
   * @param \Drupal\Core\DependencyInjection\ContainerBuilder $container
   *   The container builder.
   */
  public function register(ContainerBuilder $container): void {
    // Get config values upfront to avoid circular dependencies.
    $config = $this->getInspectorConfig();
    $enableQueryLogging = $config['enable_query_logging'] ?? FALSE;
    $ingestionKey = $config['ingestion_key'] ?? '';
    $transport = $config['transport'] ?? 'sync';

    // Register inspector service with direct config values.
    $container->register('inspector_monitoring.inspector', Inspector::class)
      ->setFactory([Inspector::class, 'create'])
      ->setArguments([$ingestionKey, $transport]);

    if ($enableQueryLogging) {
      // Set the priority to 10 to ensure it runs after the kernel events
      // have been launched, so that the inspector transaction has already
      // been initialized.
      $container->register('inspector_monitoring.db_events_enabler', DBEventsEnabler::class)
        ->addArgument(new Reference('database'))
        ->addTag('http_middleware', ['priority' => 10]);

      $container->register('inspector_monitoring.db_events_subscriber', DBEventsSubscriber::class)
        ->addArgument(new Reference('inspector_monitoring.inspector'))
        ->addTag('event_subscriber');
    }
  }

  /**
   * Get the inspector configuration.
   *
   * @return array
   *   The inspector configuration.
   */
  private function getInspectorConfig(): array {
    $config = BootstrapConfigStorageFactory::get()->read('inspector_monitoring.settings');
    return is_array($config) ? $config : [];
  }

}
