<?php

namespace Drupal\inspector_monitoring\Middleware;

use Drupal\Core\Database\Connection;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpKernel\HttpKernelInterface;
use Drupal\Core\Database\Event\StatementEvent;

/**
 * Middleware to enable database query logging events.
 *
 * This middleware checks if query logging is enabled in the module's
 * configuration.
 * If enabled, it activates event tracking for all database statements.
 */
class DBEventsEnabler implements HttpKernelInterface {

  /**
   * Constructs the middleware with required dependencies.
   *
   * @param \Symfony\Component\HttpKernel\HttpKernelInterface $httpKernel
   *   The HTTP kernel to delegate request handling.
   * @param \Drupal\Core\Database\Connection $connection
   *   The database connection service.
   */
  public function __construct(
    protected readonly HttpKernelInterface $httpKernel,
    protected readonly Connection $connection,
  ) {
  }

  /**
   * Handles the request and enables database events.
   *
   * @param \Symfony\Component\HttpFoundation\Request $request
   *   The incoming request object.
   * @param int $type
   *   The type of request (main or sub-request).
   * @param bool $catch
   *   Whether to catch exceptions.
   *
   * @return \Symfony\Component\HttpFoundation\Response
   *   The HTTP response.
   */
  public function handle(Request $request, $type = self::MAIN_REQUEST, $catch = TRUE): Response {
    // Enable database query logging if the main request.
    if ($type === static::MAIN_REQUEST) {
      $this->connection->enableEvents(StatementEvent::all());
    }

    // Continue processing the request.
    return $this->httpKernel->handle($request, $type, $catch);
  }

}
