<?php

namespace Drupal\inspector_monitoring\Subscribers;

use Drupal\inspector_monitoring\Service\Inspector;
use Inspector\Models\Segment;
use Inspector\Models\Transaction;

/**
 *
 */
trait InspectorAwareTrait {
  /**
   * @var \Drupal\inspector_monitoring\Service\Inspector
   */
  protected Inspector $inspector;

  /**
   * @var \Inspector\Models\Segment[]
   */
  protected $segments = [];

  /**
   * Be sure to start a transaction before report the exception.
   *
   * @throws \Exception
   */
  protected function startTransaction(string $name): ?Transaction {
    if ($this->inspector->needTransaction()) {
      return $this->inspector->startTransaction($name);
    }

    return $this->inspector->transaction();
  }

  /**
   * Start a new segment.
   *
   * @param string $type
   *   The type of segment to start.
   * @param string|null $label
   *   The label of the segment to start.
   *
   * @return \Inspector\Models\Segment
   *   The started segment.
   */
  protected function startSegment(string $type, ?string $label = NULL): Segment {
    $segment = $this->inspector->startSegment($type, $label);

    $this->segments[$label] = $segment;

    return $segment;
  }

  /**
   * Terminate the segment.
   *
   * @param string $label
   *   The label of the segment to end.
   */
  protected function endSegment(string $label): void {
    if (!isset($this->segments[$label])) {
      return;
    }

    $this->segments[$label]->end();

    unset($this->segments[$label]);
  }

}
